@@ -1,7 +1,7 @@
 # coding:utf-8
 import json
 
-from ks3.exception import S3ResponseError
+from ks3.exception import KS3ResponseError
 from ks3.http import make_request_v4
 
 
@@ -19,5 +19,5 @@ def get_buckets_data(access_key_id, access_key_secret, bucket_names, start_time,
                                region='cn-beijing-6', query_args=query_args)
     body = response.read()
     if response.status != 200:
-        raise S3ResponseError(response.status, response.reason, body)
+        raise KS3ResponseError(response.status, response.reason, body)
     return json.loads(body)
\ No newline at end of file
