@@ -282,35 +282,40 @@ class Bucket(object):
         """
         return BucketListResultSet(self, prefix, delimiter, marker, max_keys)
 
-    def listObjects(self, prefix=None, delimiter=None, marker=None, startTime=None, endTime=None,
-                    filename=None):
-
-        keys = self.list(prefix, delimiter, marker)
+    def listObjects(self, prefix=None, delimiter=None, marker=None, max_keys=None, startTime=None, endTime=None,
+                    filename=None, start_time=None, end_time=None):
+        if start_time is not None:
+            startTime = start_time
+        if end_time is not None:
+            endTime = end_time
+        keys = self.list(prefix, delimiter, marker, max_keys)
         keyLists = list()
         fd = None
         if filename is not None:
             fd = open(filename, "a")  # 利用追加模式,参数从w替换为a即可
             fd.seek(0)
         for k in keys:
-            datetime = int(round(parser.parse(k.last_modified).timestamp()))
-            if startTime is None and endTime is not None:
-                if (datetime >= endTime):
+            if isinstance(k, Key):
+                datetime = int(round(parser.parse(k.last_modified).timestamp()))
+                if startTime is None and endTime is not None:
+                    if (datetime >= endTime):
+                        keyLists.append(k.name)
+                        if fd:
+                            fd.write("{}\n".format(k.name))
+                elif endTime is None and startTime is not None:
+                    if (datetime <= startTime):
+                        keyLists.append(k.name)
+                        if fd:
+                            fd.write("{}\n".format(k.name))
+                elif endTime is not None and startTime is not None:
+                    if (startTime <= datetime & datetime <= endTime):
+                        keyLists.append(k.name)
+                        if fd:
+                            fd.write("{}\n".format(k.name))
+                elif endTime is None and startTime is None:
                     keyLists.append(k.name)
                     if fd:
                         fd.write("{}\n".format(k.name))
-            elif endTime is None and startTime is not None:
-                if (datetime <= startTime):
-                    keyLists.add(k.name)
-                    if fd:
-                        fd.write("{}\n".format(k.name))
-            elif endTime is not None and startTime is not None:
-                if (startTime <= datetime & datetime <= endTime):
-                    keyLists.add(k.name)
-                    if fd:
-                        fd.write("{}\n".format(k.name))
-            elif endTime is None and startTime is None:
-                if fd:
-                    fd.write("{}\n".format(k.name))
 
         if fd:
             fd.flush()
