@@ -13,9 +13,8 @@ import xml.sax
 from ks3 import auth
 from ks3 import handler
 from ks3 import utils
-from ks3.bucket import Bucket
-from ks3.bucket import BucketLocation
-from ks3.exception import S3ResponseError, S3CreateError, KS3ClientError
+from ks3.bucket import Bucket, BucketLocation
+from ks3.exception import S3ResponseError, S3CreateError, KS3ClientError, KS3ResponseError
 from ks3.http import make_request
 from ks3.provider import Provider
 from ks3.resultset import ResultSet
@@ -196,6 +195,14 @@ class Connection(object):
     def get_bucket(self, bucket_name, headers=None):
         return Bucket(self, bucket_name)
 
+    def head_bucket(self, bucket_name, headers=None):
+        response = self.make_request('HEAD', bucket_name)
+        body = response.read()
+        if response.status == 200:
+            return response.headers
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
     def get_bucket_location(self, bucket_name):
         response = self.make_request('GET', bucket_name, query_args='location')
         body = response.read()
